//+------------------------------------------------------------------+
//|                                                 ATR Channels.mq4 |
//|                         Copyright  2005, Luis Guilherme Damiani |
//|                                      http://www.damianifx.com.br |
//+------------------------------------------------------------------+
//2008fxtsd    ki    mtf keris f-la 

#property copyright "Copyright  2005, Luis Guilherme Damiani"
#property link      "http://www.damianifx.com.br"

#property indicator_chart_window
#property  indicator_buffers 7

#property  indicator_color1  Green       //Moving Average
#property  indicator_color2  DeepSkyBlue // Lower band 1
#property  indicator_color3  DeepSkyBlue // Upper band 1
#property  indicator_color4  Blue        // Lower band 2
#property  indicator_color5  Blue        // Upper band 2
#property  indicator_color6  Red         // Lower band 3
#property  indicator_color7  Red         // Upper band 3

//---- indicator buffers
double Ch1up_Buffer1[];
double Ch1dn_Buffer2[];
double Ch2up_Buffer3[];
double Ch2dn_Buffer4[];
double Ch3up_Buffer5[];
double Ch3dn_Buffer6[];

//---- input parameters
extern int    PeriodsATR = 18;
extern int    MA_Periods = 49;
extern int    MA_type = MODE_EMA;
extern int    MA_Price= 0;

extern int    TimeFrame=0;

extern double Mult_Factor1 = 1.6;
extern double Mult_Factor2 = 3.2;
extern double Mult_Factor3 = 4.8;



extern string   note_Price = "0C 1O 2H 3L 4Md 5Tp 6WghC: Md(HL/2)4,Tp(HLC/3)5,Wgh(HLCC/4)6";
extern string   MA_Method_ = "SMA0 EMA1 SMMA2 LWMA3";
extern string   TimeFrames = "M1;5,15,30,60H1;240H4;1440D1;10080W1;43200MN";

double ma[], atr[];
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
   string mat;
   
   IndicatorBuffers(8);
   
   TimeFrame= MathMax(TimeFrame, Period());

//---7- indicators
// MA
   SetIndexStyle(0, DRAW_LINE);
   SetIndexBuffer(0, ma);
   SetIndexDrawBegin(0, MathMax(PeriodsATR, MA_Periods));
   string  sATRma = StringConcatenate("ATR MA(", PeriodsATR, ", ", MA_Periods,")[", TimeFrame, "]"); 
   SetIndexLabel(0, sATRma);

  // ATR 1 up
   SetIndexStyle(1, DRAW_LINE);
   SetIndexBuffer(1, Ch1up_Buffer1);
   SetIndexDrawBegin(1, MathMax(PeriodsATR, MA_Periods));
   string  sATRu1 = StringConcatenate("ATRu(", PeriodsATR, ", ", Mult_Factor1, ")[",TimeFrame,"]"); 
   SetIndexLabel(1, sATRu1);
  // ATR 1 down
   SetIndexStyle(2, DRAW_LINE);
   SetIndexBuffer(2, Ch1dn_Buffer2);
   SetIndexDrawBegin(2, MathMax(PeriodsATR, MA_Periods));
   string  sATRd1 = StringConcatenate("ATRd(", PeriodsATR, ", ", Mult_Factor1,  ")[",TimeFrame,"]"); 
   SetIndexLabel(2, sATRd1);
// ATR 2 up
   SetIndexStyle(3, DRAW_LINE);
   SetIndexBuffer(3, Ch2up_Buffer3);
   SetIndexDrawBegin(3, MathMax(PeriodsATR, MA_Periods));
   string  sATRu2 = StringConcatenate("ATRu(", PeriodsATR, ", ", Mult_Factor2,  ")[",TimeFrame,"]"); 
   SetIndexLabel(3, sATRu2);
  // ATR 2 down
   SetIndexStyle(4, DRAW_LINE);
   SetIndexBuffer(4, Ch2dn_Buffer4);
   SetIndexDrawBegin(4, MathMax(PeriodsATR, MA_Periods));
   string  sATRd2 = StringConcatenate("ATRd(", PeriodsATR, ", ", Mult_Factor2,  ")[",TimeFrame,"]"); 
   SetIndexLabel(4, sATRd2);
   // ATR 3 up
   SetIndexStyle(5, DRAW_LINE);
   SetIndexBuffer(5, Ch3up_Buffer5);
   SetIndexDrawBegin(5, MathMax(PeriodsATR, MA_Periods));
   string  sATRu3 = StringConcatenate("ATRu(", PeriodsATR, ", ", Mult_Factor3,  ")[",TimeFrame,"]"); 
   SetIndexLabel(5, sATRu3);
  // ATR 3 down
   SetIndexStyle(6, DRAW_LINE);
   SetIndexBuffer(6, Ch3dn_Buffer6);
   SetIndexDrawBegin(6, MathMax(PeriodsATR, MA_Periods));
   string  sATRd3 = StringConcatenate("ATRd(", PeriodsATR, ", ", Mult_Factor3,  ")[",TimeFrame,"]"); 
   SetIndexLabel(6, sATRd3);
   
   SetIndexBuffer(7, atr);

//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custor indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
   datetime TimeArray[];
   ArrayCopySeries(TimeArray ,MODE_TIME ,NULL,TimeFrame);

   int i,y;
   int fixed_bars = IndicatorCounted();
//---- check for possible errors
   if(fixed_bars < 0)        return(-1);
//---- last counted bar will be recounted
   if(fixed_bars > 0)        fixed_bars--;
   int limit = Bars - fixed_bars;
       limit = MathMax (limit,TimeFrame/Period());


//----
   for( i = 0, y=0; i < limit; i++)
     {
     if (Time[i]<TimeArray[y]) y++; 

     atr[i] = iATR(NULL, TimeFrame, PeriodsATR, y);
     ma[i]  = iMA(NULL, TimeFrame, MA_Periods, 0, MA_type, MA_Price, y);
     }
   
   for (i = 0; i < limit; i++)
       {
       Ch1up_Buffer1[i] = ma[i] + atr[i]*Mult_Factor1;
       Ch1dn_Buffer2[i] = ma[i] - atr[i]*Mult_Factor1;
       
       Ch2up_Buffer3[i] = ma[i]+ atr[i]*Mult_Factor2;
       Ch2dn_Buffer4[i] = ma[i] - atr[i]*Mult_Factor2;
       
       Ch3up_Buffer5[i] = ma[i] + atr[i]*Mult_Factor3;
       Ch3dn_Buffer6[i] = ma[i] - atr[i]*Mult_Factor3;
       }  
//----
   return(0);
  }
//+------------------------------------------------------------------+